@@ -41,7 +41,8 @@ async def test_parse(
     _get_head_ref_name: mock.Mock,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
-    monkeypatch.setenv("MERGIFY_TEST_JOB_NAME", "foobar")
+    monkeypatch.setenv("_MERGIFY_TEST_JOB_NAME", "foobar")
+    monkeypatch.setenv("MERGIFY_TEST_FLAKY_DETECTION", "1")
     filename = pathlib.Path(__file__).parent / "junit_example.xml"
     run_id = (32312).to_bytes(8, "big").hex()
     spans = await junit.junit_to_spans(
@@ -50,6 +51,9 @@ async def test_parse(
         "python",
         "unittest",
     )
+    # No traceparent on session span
+    assert spans[0].parent is None
+
     dictified_spans = [json.loads(span.to_json()) for span in spans]
     trace_id = "0x" + opentelemetry.trace.span.format_trace_id(
         spans[1].context.trace_id,
@@ -69,6 +73,7 @@ async def test_parse(
         "telemetry.sdk.name": "opentelemetry",
         "telemetry.sdk.version": anys.ANY_STR,
         "mergify.test.job.name": "foobar",
+        "mergify.test.flaky_detection_enabled": True,
     }
     assert dictified_spans == [
         {
@@ -132,6 +137,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -161,6 +167,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -193,6 +200,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -249,6 +257,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -278,6 +287,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -310,6 +320,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -343,6 +354,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -399,6 +411,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -431,6 +444,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -460,6 +474,7 @@ async def test_parse(
                 "test.scope": "case",
                 "test.framework": "unittest",
                 "test.language": "python",
+                "cicd.test.quarantined": False,
             },
             "context": {
                 "span_id": anys.ANY_STR,
@@ -482,3 +497,58 @@ async def test_parse(
             },
         },
     ]
+
+
+@mock.patch.object(detector, "get_ci_provider", return_value="github_actions")
+@mock.patch.object(detector, "get_pipeline_name", return_value="PIPELINE")
+@mock.patch.object(detector, "get_job_name", return_value="JOB")
+@mock.patch.object(
+    detector,
+    "get_cicd_pipeline_runner_name",
+    return_value="self-hosted",
+)
+@mock.patch.object(detector, "get_cicd_pipeline_run_id", return_value=123)
+@mock.patch.object(detector, "get_cicd_pipeline_run_attempt", return_value=1)
+@mock.patch.object(
+    detector,
+    "get_head_sha",
+    return_value="3af96aa24f1d32fcfbb7067793cacc6dc0c6b199",
+)
+@mock.patch.object(
+    detector,
+    "get_head_ref_name",
+    return_value="refs/heads/main",
+)
+async def test_traceparent_injection(
+    _get_ci_provider: mock.Mock,
+    _get_pipeline_name: mock.Mock,
+    _get_job_name: mock.Mock,
+    _get_cicd_pipeline_runner_name: mock.Mock,
+    _get_cicd_pipeline_run_id: mock.Mock,
+    _get_cicd_pipeline_run_attempt: mock.Mock,
+    _get_head_sha: mock.Mock,
+    _get_head_ref_name: mock.Mock,
+    monkeypatch: pytest.MonkeyPatch,
+) -> None:
+    monkeypatch.setenv(
+        "MERGIFY_TRACEPARENT",
+        "00-80e1afed08e019fc1110464cfa66635c-7a085853722dc6d2-01",
+    )
+    monkeypatch.setenv("_MERGIFY_TEST_JOB_NAME", "foobar")
+    filename = pathlib.Path(__file__).parent / "junit_example.xml"
+    run_id = (32312).to_bytes(8, "big").hex()
+    spans = await junit.junit_to_spans(
+        run_id,
+        filename.read_bytes(),
+        "python",
+        "unittest",
+    )
+    assert len(spans) == 14
+    assert spans[0].parent is not None
+    assert spans[0].parent.trace_id == 0x80E1AFED08E019FC1110464CFA66635C
+    assert spans[0].parent.span_id == 0x7A085853722DC6D2
+    for span in spans:
+        assert span.context.trace_id == 0x80E1AFED08E019FC1110464CFA66635C
+
+        # Flaky test detection is disabled by default.
+        assert "mergify.test.flaky_detection_enabled" not in span.resource.attributes
